@@ -55,7 +55,8 @@ class Ticket:
             event_date=None,
             currency=None,
             external_card_ref=None,
-            additional_fields=None
+            additional_fields=[],
+            printed=True
     ):
         self.id = id
         self.external_ticket_id = external_ticket_id
@@ -163,8 +164,8 @@ class Ticket:
         else:
             self.currency = None
 
-        if additional_fields:
-            self.additional_fields = additional_fields
+        self.additional_fields = additional_fields
+        self.printed = printed
 
     @classmethod
     def placeholder(
@@ -217,7 +218,8 @@ class Ticket:
             event=None,
             currency=None,
             external_card_ref=None,
-            additional_fields=None,
+            additional_fields=[],
+            printed=True
         )
 
     @classmethod
@@ -266,7 +268,10 @@ class Ticket:
             currency: Currency or None = None,
             external_card_ref=None,
             additional_fields=None,
+            printed=True
     ):
+        if additional_fields is None:
+            additional_fields = []
         ticket = Ticket(
             id=None,
             external_ticket_id=external_ticket_id,
@@ -313,7 +318,8 @@ class Ticket:
             event=event,
             currency=currency,
             external_card_ref=external_card_ref,
-            additional_fields=additional_fields
+            additional_fields=additional_fields,
+            printed=printed
         )
         if isinstance(user, (str, int)):
             user = User.placeholder(id=user)
@@ -381,10 +387,10 @@ class Ticket:
             'client_email', 'price', 'status', 'can_share', 'sharer_email', 'redeemed_at', 'redeemer_id', 'share_code',
             'redeemer_email', 'parent_ticket', 'shared_at', 'legal_long_text', 'legal_short_text', 'map_url',
             'map_image_url', 'ticket_integration', 'entrance', 'row', 'section', 'price_code', 'external_customer_ref',
-            'venue', 'event', 'event_date', 'currency', 'external_card_ref', 'additional_fields'
+            'venue', 'event', 'event_date', 'currency', 'external_card_ref', 'additional_fields', 'printed'
         )
         for field in fields:
-            if (hasattr(self, field) and hasattr(other, field)) and getattr(self, field) != getattr(other, field):
+            if getattr(self, field) != getattr(other, field):
                 if field == 'additional_fields' and getattr(other, field):
                     if getattr(self, field):
                         additional_fields = []
