@@ -1,6 +1,6 @@
 from marshmallow import EXCLUDE, fields, Schema
 
-from livestyled.models.user import User, UserConsent, UserEmail, UserInfo, UserSSO
+from livestyled.models.user import User, UserAlias, UserAliasType, UserConsent, UserEmail, UserInfo, UserSSO
 from livestyled.schemas.cohort import CohortSchema
 from livestyled.schemas.device import DeviceSchema
 from livestyled.schemas.fields import RelatedResourceField, RelatedResourceLinkField
@@ -58,6 +58,30 @@ class UserEmailSchema(Schema):
     id = fields.Int()
 
 
+class UserAliasTypeSchema(Schema):
+    class Meta:
+        unknown = EXCLUDE
+        api_type = 'user_alias_types'
+        url = 'user_management/user_alias_types'
+        model = UserAliasType
+
+    user_alias_type = fields.String(data_key='userAliasType', missing=None, allow_none=True)
+
+
+class UserAliasSchema(Schema):
+    class Meta:
+        unknown = EXCLUDE
+        api_type = 'user_aliases'
+        url = 'user_management/user_aliases'
+        model = UserAlias
+
+    id = fields.Int()
+    user_alias_type = RelatedResourceLinkField(data_key='userAliasType', schema=UserAliasTypeSchema, microservice_aware=True)
+    value = fields.String(missing=None)
+    updated_at = fields.AwareDateTime(data_key='updatedAt', allow_none=True, missing=None)
+    created_at = fields.AwareDateTime(data_key='createdAt', allow_none=True, missing=None)
+
+
 class UserSchema(Schema):
     class Meta:
         unknown = EXCLUDE
@@ -80,6 +104,7 @@ class UserSchema(Schema):
     user_emails = RelatedResourceField(schema=UserEmailSchema, data_key='userEmails', many=True)
     user_consent = RelatedResourceField(schema=UserConsentSchema, data_key='userConsent')
     token = fields.String(missing=None)
+    user_aliases = RelatedResourceField(schema=UserAliasSchema, data_key='userAliases', many=True, missing=[])
 
 
 class UserSSOSchema(Schema):
